@@ -471,7 +471,6 @@ func NewAgentConfig(c *Config, logOptions []log.Option, allowUnknownConfig bool)
 	}
 	ac.DisableSPIFFECertValidation = c.Agent.SDS.DisableSPIFFECertValidation
 
-	ac.InsecureBootstrap = c.Agent.InsecureBootstrap
 	ts := &trustbundlesources.Config{
 		InsecureBootstrap:     c.Agent.InsecureBootstrap,
 		TrustBundleFormat:     c.Agent.TrustBundleFormat,
@@ -479,10 +478,8 @@ func NewAgentConfig(c *Config, logOptions []log.Option, allowUnknownConfig bool)
 		TrustBundleURL:        c.Agent.TrustBundleURL,
 		TrustBundleUnixSocket: c.Agent.TrustBundleUnixSocket,
 	}
-	err = trustbundlesources.SetupTrustBundle(ac, ts)
-	if err != nil {
-		return nil, err
-	}
+
+	ac.TrustBundleSources = trustbundlesources.New(ts, ac.Log.WithField("Logger", "TrustBundleSources"))
 
 	ac.WorkloadKeyType = workloadkey.ECP256
 	if c.Agent.WorkloadX509SVIDKeyType != "" {
