@@ -1198,15 +1198,6 @@ func TestFetchSecrets(t *testing.T) {
 	}
 }
 
-func DeltaSecretsTest(t *testing.T) {
-	test := setupTest(t)
-	defer test.cleanup()
-
-	resp, err := test.handler.DeltaSecrets(context.Background())
-	spiretest.RequireGRPCStatus(t, err, codes.Unimplemented, "Method is not implemented")
-	require.Nil(t, resp)
-}
-
 func setupTest(t *testing.T) *handlerTest {
 	return setupTestWithManager(t, Config{}, NewFakeManager(t))
 }
