@@ -9,7 +9,6 @@ import (
 
 	"github.com/go-jose/go-jose/v4/jwt"
 	"github.com/spiffe/go-spiffe/v2/spiffeid"
-	"github.com/zeebo/errs"
 )
 
 type KeyStore interface {
@@ -41,17 +40,17 @@ func (t *keyStore) FindPublicKey(_ context.Context, td spiffeid.TrustDomain, key
 func ValidateToken(ctx context.Context, token string, keyStore KeyStore, audience []string) (spiffeid.ID, map[string]any, error) {
 	tok, err := jwt.ParseSigned(token, AllowedSignatureAlgorithms)
 	if err != nil {
-		return spiffeid.ID{}, nil, errs.New("unable to parse JWT token: %v", err)
+		return spiffeid.ID{}, nil, fmt.Errorf("unable to parse JWT token: %w", err)
 	}
 
 	if len(tok.Headers) != 1 {
-		return spiffeid.ID{}, nil, errs.New("expected a single token header; got %d", len(tok.Headers))
+		return spiffeid.ID{}, nil, fmt.Errorf("expected a single token header; got %d", len(tok.Headers))
 	}
 
 	// Obtain the key ID from the header
 	keyID := tok.Headers[0].KeyID
 	if keyID == "" {
-		return spiffeid.ID{}, nil, errs.New("token header missing key id")
+		return spiffeid.ID{}, nil, fmt.Errorf("token header missing key id")
 	}
 
 	// Parse out the unverified claims. We need to look up the key by the trust
@@ -59,14 +58,17 @@ func ValidateToken(ctx context.Context, token string, keyStore KeyStore, audienc
 	// when creating the generic map of claims that we return to the caller.
 	var claims jwt.Claims
 	if err := tok.UnsafeClaimsWithoutVerification(&claims); err != nil {
-		return spiffeid.ID{}, nil, errs.Wrap(err)
+		return spiffeid.ID{}, nil, err
 	}
 	if claims.Subject == "" {
-		return spiffeid.ID{}, nil, errs.New("token missing subject claim")
+		return spiffeid.ID{}, nil, errors.New("token missing subject claim")
+	}
+	if claims.Expiry == nil {
+		return spiffeid.ID{}, nil, errors.New("token missing exp claim")
 	}
 	spiffeID, err := spiffeid.FromString(claims.Subject)
 	if err != nil {
-		return spiffeid.ID{}, nil, errs.New("token has in invalid subject claim: %v", err)
+		return spiffeid.ID{}, nil, fmt.Errorf("token has in invalid subject claim: %w", err)
 	}
 
 	// Construct the trust domain id from the SPIFFE ID and look up key by ID
@@ -78,7 +80,7 @@ func ValidateToken(ctx context.Context, token string, keyStore KeyStore, audienc
 	// Now obtain the generic claims map verified using the obtained key
 	claimsMap := make(map[string]any)
 	if err := tok.Claims(key, &claimsMap); err != nil {
-		return spiffeid.ID{}, nil, errs.Wrap(err)
+		return spiffeid.ID{}, nil, err
 	}
 
 	// Now that the signature over the claims has been verified, validate the
@@ -90,11 +92,9 @@ func ValidateToken(ctx context.Context, token string, keyStore KeyStore, audienc
 		// Convert expected validation errors for pretty errors
 		switch {
 		case errors.Is(err, jwt.ErrExpired):
-			err = errs.New("token has expired")
+			err = errors.New("token has expired")
 		case errors.Is(err, jwt.ErrInvalidAudience):
-			err = errs.New("expected audience in %q (audience=%q)", audience, claims.Audience)
-		default:
-			err = errs.Wrap(err)
+			err = fmt.Errorf("expected audience in %q (audience=%q)", audience, claims.Audience)
 		}
 		return spiffeid.ID{}, nil, err
 	}
