@@ -7,8 +7,10 @@ import (
 	"path/filepath"
 	"testing"
 
-	"github.com/open-policy-agent/opa/storage/inmem"
-	"github.com/open-policy-agent/opa/util"
+	"github.com/open-policy-agent/opa/v1/ast"
+	"github.com/open-policy-agent/opa/v1/storage/inmem"
+	"github.com/open-policy-agent/opa/v1/util"
+	"github.com/sirupsen/logrus/hooks/test"
 	"github.com/spiffe/spire/pkg/server/authpolicy"
 	"github.com/stretchr/testify/require"
 )
@@ -209,7 +211,6 @@ func TestPolicy(t *testing.T) {
 			},
 		},
 	} {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			var json map[string]any
 			err := util.UnmarshalJSON([]byte(tt.jsonData), &json)
@@ -220,7 +221,7 @@ func TestPolicy(t *testing.T) {
 			ctx := context.Background()
 
 			// Check with NewEngineFromRego
-			pe, err := authpolicy.NewEngineFromRego(ctx, tt.rego, store)
+			pe, err := authpolicy.NewEngineFromRego(ctx, tt.rego, store, ast.RegoV1)
 			require.Nil(t, err, "failed to create policy engine")
 
 			res, err := pe.Eval(ctxIn, tt.input)
@@ -230,20 +231,22 @@ func TestPolicy(t *testing.T) {
 
 			// Check with NewEngineFromConfigOrDefault
 			regoFile := filepath.Join(tmpDir, "rego_file")
-			err = os.WriteFile(regoFile, []byte(tt.rego), 0600)
+			err = os.WriteFile(regoFile, []byte(tt.rego), 0o600)
 			require.Nil(t, err, "failed to create rego_file")
 
 			permsFile := filepath.Join(tmpDir, "perms_file")
-			err = os.WriteFile(permsFile, []byte(tt.jsonData), 0600)
+			err = os.WriteFile(permsFile, []byte(tt.jsonData), 0o600)
 			require.Nil(t, err, "failed to create perms_file")
 
 			ec := authpolicy.OpaEngineConfig{
 				LocalOpaProvider: &authpolicy.LocalOpaProviderConfig{
 					RegoPath:       regoFile,
 					PolicyDataPath: permsFile,
+					UseRegoV1:      true,
 				},
 			}
-			pe, err = authpolicy.NewEngineFromConfigOrDefault(ctx, &ec)
+			log, _ := test.NewNullLogger()
+			pe, err = authpolicy.NewEngineFromConfigOrDefault(ctx, log, &ec)
 
 			require.Nil(t, err, "failed to create policy engine")
 
@@ -271,20 +274,20 @@ func TestNewEngineFromConfig(t *testing.T) {
 
 	// Create good policy/perms files
 	validRegoFile := filepath.Join(tmpDir, "valid_rego_file")
-	err = os.WriteFile(validRegoFile, []byte(rego), 0600)
+	err = os.WriteFile(validRegoFile, []byte(rego), 0o600)
 	require.Nil(t, err, "failed to create valid_rego_file")
 
 	validPermsFile := filepath.Join(tmpDir, "valid_perms_file")
-	err = os.WriteFile(validPermsFile, []byte(jsonData), 0600)
+	err = os.WriteFile(validPermsFile, []byte(jsonData), 0o600)
 	require.Nil(t, err, "failed to create valid_perms_file")
 
 	// Create bad policy/perms files
 	invalidRegoFile := filepath.Join(tmpDir, "invalid_rego_file")
-	err = os.WriteFile(invalidRegoFile, []byte("invalid rego"), 0600)
+	err = os.WriteFile(invalidRegoFile, []byte("invalid rego"), 0o600)
 	require.Nil(t, err, "failed to create invalid_rego_file")
 
 	invalidPermsFile := filepath.Join(tmpDir, "invalid_perms_file")
-	err = os.WriteFile(invalidPermsFile, []byte("{"), 0600)
+	err = os.WriteFile(invalidPermsFile, []byte("{"), 0o600)
 	require.Nil(t, err, "failed to create invalid_perms_file")
 
 	// Create permissions tmp file
@@ -386,11 +389,11 @@ func TestNewEngineFromConfig(t *testing.T) {
 			success: false,
 		},
 	} {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			ctx := context.Background()
 
-			_, err := authpolicy.NewEngineFromConfigOrDefault(ctx, tt.ec)
+			log, _ := test.NewNullLogger()
+			_, err := authpolicy.NewEngineFromConfigOrDefault(ctx, log, tt.ec)
 			require.Equal(t, err == nil, tt.success)
 		})
 	}
@@ -425,14 +428,13 @@ func TestNewEngineFromRego(t *testing.T) {
 			success: false,
 		},
 	} {
-		tt := tt
 		t.Run(tt.name, func(t *testing.T) {
 			ctx := context.Background()
 			// Just create arbitrary store since there isn't a way to create
 			// a bad store
 			store := inmem.New()
 
-			_, err := authpolicy.NewEngineFromRego(ctx, tt.rego, store)
+			_, err := authpolicy.NewEngineFromRego(ctx, tt.rego, store, ast.RegoV1)
 			require.Equal(t, err == nil, tt.success)
 		})
 	}
@@ -450,7 +452,7 @@ func condCheckRego(cond string) string {
     }
     default allow = false
 
-    allow=true {
+    allow=true if {
         %s
     }
     `
@@ -479,7 +481,7 @@ var badEvalPolicy = `
     }
     default allow = false
 
-    allow=true {
+    allow=true if {
         %s
     }
     `
