@@ -35,6 +35,7 @@ type DataStore interface {
 	CreateOrReturnRegistrationEntry(context.Context, *common.RegistrationEntry) (*common.RegistrationEntry, bool, error)
 	DeleteRegistrationEntry(ctx context.Context, entryID string) (*common.RegistrationEntry, error)
 	FetchRegistrationEntry(ctx context.Context, entryID string) (*common.RegistrationEntry, error)
+	FetchRegistrationEntries(ctx context.Context, entryIDs []string) (map[string]*common.RegistrationEntry, error)
 	ListRegistrationEntries(context.Context, *ListRegistrationEntriesRequest) (*ListRegistrationEntriesResponse, error)
 	PruneRegistrationEntries(ctx context.Context, expiresBefore time.Time) error
 	UpdateRegistrationEntry(context.Context, *common.RegistrationEntry, *common.RegistrationEntryMask) (*common.RegistrationEntry, error)
@@ -170,6 +171,7 @@ type ListAttestedNodesResponse struct {
 }
 
 type ListAttestedNodeEventsRequest struct {
+	DataConsistency    DataConsistency
 	GreaterThanEventID uint
 	LessThanEventID    uint
 }
@@ -224,6 +226,7 @@ type ListRegistrationEntriesResponse struct {
 }
 
 type ListRegistrationEntryEventsRequest struct {
+	DataConsistency    DataConsistency
 	GreaterThanEventID uint
 	LessThanEventID    uint
 }
