@@ -92,6 +92,7 @@ func (s *Server) run(ctx context.Context) (err error) {
 		FileConfig:  s.config.Telemetry,
 		Logger:      s.config.Log.WithField(telemetry.SubsystemName, telemetry.Telemetry),
 		ServiceName: telemetry.SpireServer,
+		TrustDomain: s.config.TrustDomain.Name(),
 	})
 	if err != nil {
 		return err
@@ -162,7 +163,7 @@ func (s *Server) run(ctx context.Context) (err error) {
 		return err
 	}
 
-	authPolicyEngine, err := authpolicy.NewEngineFromConfigOrDefault(ctx, s.config.AuthOpaPolicyEngineConfig)
+	authPolicyEngine, err := authpolicy.NewEngineFromConfigOrDefault(ctx, s.config.Log, s.config.AuthOpaPolicyEngineConfig)
 	if err != nil {
 		return fmt.Errorf("unable to obtain authpolicy engine: %w", err)
 	}
@@ -211,7 +212,7 @@ func (s *Server) run(ctx context.Context) (err error) {
 		registrationManager.Run,
 		bundlePublishingManager.Run,
 		catalog.ReconfigureTask(s.config.Log.WithField(telemetry.SubsystemName, "reconfigurer"), cat),
-		util.SerialRun(s.waitForTestDial, healthChecker.ListenAndServe),
+		healthChecker.ListenAndServe,
 	}
 
 	if s.config.LogReopener != nil {
@@ -283,7 +284,8 @@ func (s *Server) setupProfiling(ctx context.Context) (stop func()) {
 }
 
 func (s *Server) loadCatalog(ctx context.Context, metrics telemetry.Metrics, identityProvider *identityprovider.IdentityProvider, agentStore *agentstore.AgentStore,
-	healthChecker health.Checker) (*catalog.Repository, error) {
+	healthChecker health.Checker,
+) (*catalog.Repository, error) {
 	return catalog.Load(ctx, catalog.Config{
 		Log:              s.config.Log.WithField(telemetry.SubsystemName, telemetry.Catalog),
 		Metrics:          metrics,
@@ -400,7 +402,7 @@ func (s *Server) newEndpointsServer(ctx context.Context, catalog catalog.Catalog
 		CacheReloadInterval:          s.config.CacheReloadInterval,
 		EventsBasedCache:             s.config.EventsBasedCache,
 		PruneEventsOlderThan:         s.config.PruneEventsOlderThan,
-		SQLTransactionTimeout:        s.config.SQLTransactionTimeout,
+		EventTimeout:                 s.config.EventTimeout,
 		AuditLogEnabled:              s.config.AuditLogEnabled,
 		AuthPolicyEngine:             authPolicyEngine,
 		BundleManager:                bundleManager,
@@ -447,8 +449,8 @@ func (s *Server) validateTrustDomain(ctx context.Context, ds datastore.DataStore
 		Pagination: &datastore.Pagination{
 			Token:    "",
 			PageSize: pageSize,
-		}})
-
+		},
+	})
 	if err != nil {
 		return err
 	}
@@ -469,7 +471,8 @@ func (s *Server) validateTrustDomain(ctx context.Context, ds datastore.DataStore
 		Pagination: &datastore.Pagination{
 			Token:    "",
 			PageSize: pageSize,
-		}})
+		},
+	})
 	if err != nil {
 		return err
 	}
@@ -489,14 +492,6 @@ func (s *Server) validateTrustDomain(ctx context.Context, ds datastore.DataStore
 	return nil
 }
 
-// waitForTestDial calls health.WaitForTestDial to wait for a connection to the
-// SPIRE Server API socket. This function always returns nil, even if
-// health.WaitForTestDial exited due to a timeout.
-func (s *Server) waitForTestDial(ctx context.Context) error {
-	health.WaitForTestDial(ctx, s.config.BindLocalAddress)
-	return nil
-}
-
 // CheckHealth is used as a top-level health check for the Server.
 func (s *Server) CheckHealth() health.State {
 	err := s.tryGetBundle()
@@ -518,9 +513,14 @@ func (s *Server) CheckHealth() health.State {
 }
 
 func (s *Server) tryGetBundle() error {
-	client, err := server_util.NewServerClient(s.config.BindLocalAddress)
+	addr, err := util.GetTargetName(s.config.BindLocalAddress)
 	if err != nil {
-		return errors.New("cannot create registration client")
+		return fmt.Errorf("cannot get local gRPC address: %w", err)
+	}
+
+	client, err := server_util.NewServerClient(addr)
+	if err != nil {
+		return fmt.Errorf("cannot create registration client: %w", err)
 	}
 	defer client.Release()
 
@@ -531,7 +531,7 @@ func (s *Server) tryGetBundle() error {
 	// As currently coded however, the API isn't served until after
 	// the server CA has been signed by upstream.
 	if _, err := bundleClient.GetBundle(context.Background(), &bundlev1.GetBundleRequest{}); err != nil {
-		return errors.New("unable to fetch bundle")
+		return fmt.Errorf("unable to fetch bundle: %w", err)
 	}
 	return nil
 }
